SharedDevice Class — pysmb 1.1.21 documentation

# SharedDevice Class

class `smb.base.` `SharedDevice`(type, name, comments)

  Contains information about a single shared device on the remote server.

  `comments` = None

    An unicode string containing the user description of the shared device

  `isSpecial`

    Returns True if this shared device is a special share reserved for interprocess communication (IPC$) or remote administration of the server (ADMIN$). Can also refer to administrative shares such as C$, D$, E$, and so forth

  `isTemporary`

    Returns True if this is a temporary share that is not persisted for creation each time the file server initializes.

  `name` = None

    An unicode string containing the name of the shared device

  `type`
    Returns one of the following integral constants.
      - SharedDevice.DISK_TREE
      - SharedDevice.PRINT_QUEUE
      - SharedDevice.COMM_DEVICE
      - SharedDevice.IPC